@@ -125,10 +125,6 @@ extern "C" {
 #define ATOM_SINF 24
 #define ATOM_SCHI 25
 
-#ifdef HAVE_CONFIG_H
-#include "../config.h"   
-#endif
-
 #if !(defined(_WIN32) || defined(_WIN32_WCE))
 #define stricmp strcasecmp
 #else
